RIFLE
========

RISC-V Feature Legalizer

LICENSE: BSD-3 Clause.

Latest Documentation of RIFLE:

  * `HTML <https://rifle.readthedocs.io/>`_
  * `PDF  <https://gitlab.com/incoresemi/rifle/-/jobs/artifacts/master/raw/RIFLE.pdf?job=doc>`_
